<?php

final class Lighthouse extends Conexion{

    public $id_tipo_dispositivo;
    public $nombre_tipo_dispositivo;
    public $id_requestedUrl;
    public $nombre_requestedUrl;
    public $id_final_url;
    public $nombre_finalUrl;
    public $id_category;
    public $category;
    public $id_name_category;
    public $name_category;
    public $id_title;
    public $title;
    public $id_type;
    public $type;
    public $score;
    public $fecha_registro;

    function Lighthouse_TipoDispositivo(){
        $datos = array($this->nombre_tipo_dispositivo);
        $this->Asignar("CALL Lighthouse_TipoDispositivo(?)", 'Buscar crear request URL', $datos);
        return $this->DatoUnico();
    }

    function BuscarCrearRequestedURL(){
        $datos = array($this->nombre_requestedUrl);
        print_r($datos);
        $this->Asignar("CALL Lighthouse_BuscarCrearRequestedURL(?)", 'Buscar crear request URL', $datos);
        return $this->DatoUnico();
    }

    function BuscarCrearNombreFinalUrl(){
        $datos = array($this->nombre_finalUrl);
        $this->Asignar("CALL Lighthouse_BuscarCrearNombreFinalUrl(?)", 'Buscar crear nombre final URL', $datos);
        return $this->DatoUnico();
    }

    function BuscarCrearCategory(){
        $datos = array($this->category);
        $this->Asignar("CALL Lighthouse_BuscarCrearCategory(?)", 'Buscar crear categoria', $datos);
        return $this->DatoUnico();
    }

    function BuscarCrearNameCategory(){
        $datos = array($this->id_category,$this->name_category);
        $this->Asignar("CALL Lighthouse_BuscarCrearNameCategory(?,?)", 'Buscar crear nombre categoria', $datos);
        return $this->DatoUnico();
    }

    function BuscarCrearTitle(){
        $datos = array($this->id_name_category, $this->title);
        $this->Asignar("CALL Lighthouse_BuscarCrearTitle(?,?)", 'Buscar crear Title', $datos);
        return $this->DatoUnico();
    }

    function BuscarCrearType(){
        $datos = array($this->type);
        $this->Asignar("CALL Lighthouse_BuscarCrearType(?)", 'Buscar crear Type', $datos);
        return $this->DatoUnico();
    }

    function InsertRegistro(){
        $datos = array(
            $this->id_requestedUrl,
            $this->id_final_url,
            $this->id_title,
            $this->id_type,
            $this->score,
            $this->id_tipo_dispositivo,
            $this->fecha_registro
        );
        $this->Asignar("CALL Lighthouse_InsertRegistro(?,?,?,?,?,?,?)", 'Insertar registro', $datos);
        return $this->ConsultaIndividual();
    }

    function BuscarScoreGeneral(){
        $datos = array(
            vacioIgualNulo($this->filtro),
            vacioIgualNulo($this->dias_atras)
        );
        $this->Asignar("CALL Lighthouse_BuscarScoreGeneral(?,?)", 'Buscar score General', $datos);
        return $this->ListarDatos();
    }
    
}