<?php
echo '<pre>';
$ruta_proyecto = '/var/www/html/lighthouse/';
require 'funciones-aux.php';
$ruta_cron  = $ruta_proyecto .'cron/';
$ruta_clase = $ruta_proyecto .'clases/';
$ruta_conf  = $ruta_proyecto .'conf/';

require $ruta_cron . 'funciones-cron.php';

require $ruta_conf . 'propiedades.php';
require $ruta_clase . 'conexion-class.php';
require $ruta_clase . 'lighthouse-class.php';

require $ruta_clase . 'excel-class.php';

$_excel         = New Excel();
$_lighthouse    = new Lighthouse();

echo 'Iniciando Proceso' . "\n";
$arr_carpetas = array('desktop', 'movil');
$ruta_archivo   = $ruta_proyecto . 'archivos/lighthouse/';

foreach($arr_carpetas as $ac){
    $ruta_carpeta_final = $ruta_archivo . $ac . '/';
    $leer_archivos      = glob($ruta_carpeta_final . '*');
    
    $_lighthouse->nombre_tipo_dispositivo   = $ac;
    $id_tipo_dispositivo                    = $_lighthouse->Lighthouse_TipoDispositivo();
    $_lighthouse->id_tipo_dispositivo       = $id_tipo_dispositivo;
    echo "\n Procesando archivos {$ac}\n";

    foreach($leer_archivos as $la){
        $arr_datos          = explode('/', $la);
        $tamaño_arreglo     = count($arr_datos)-1;
        $nombre_archivo     = $arr_datos[$tamaño_arreglo];
        $resto_fecha        = explode('----',$nombre_archivo);
        $resto_fecha        = $resto_fecha[1];
        $fecha_sin_procesar = explode('.',$resto_fecha);
        $fecha_sin_procesar = $fecha_sin_procesar[0];
        $fecha_sin_procesar = explode('--',$fecha_sin_procesar);
        
        $fecha_sin_hora     = $fecha_sin_procesar[0];
        $solo_hora          = $fecha_sin_procesar[1];
        $solo_hora          = str_replace('_', ':', $solo_hora);

        $fecha_registro                 = $fecha_sin_hora . ' ' . $solo_hora;
        $_lighthouse->fecha_registro    = $fecha_registro;

        echo "\n\t nombre archivo: {$nombre_archivo} \n\n";

        //leer datos del excel
        $_excel->Leer($ruta_carpeta_final . $nombre_archivo);
        $total_hojas        = $_excel->TotalHojas();
        $hoja_actual        = $_excel->SeleccionarHoja(0);
        $total_filas        = $_excel->TotalFilas();
        $cont               = 0;

        for($i = 0; $i <$total_hojas; ++$i){
            $hoja_actual    = $_excel->SeleccionarHoja($i);
            $cont = 0;
            for($indice_fila = 2; $indice_fila<=$total_filas; ++$indice_fila){
                
                //$dato_celda       = $_excel->valorCelda(1, $indice_fila);
                //$dato       = str_replace('<', '--' ,$dato);
                //$dato       = str_replace('>', '--' ,$dato);
                //$arr_celda  = explode(',"', $dato_celda);
                $nombre_requestedUrl    = $_excel->valorCelda(1, $indice_fila);
                $nombre_finalUrl        = $_excel->valorCelda(2, $indice_fila);
                $category               = $_excel->valorCelda(3, $indice_fila);
                $name_category          = $_excel->valorCelda(4, $indice_fila);
                $title                  = $_excel->valorCelda(5, $indice_fila);
                $type                   = $_excel->valorCelda(6, $indice_fila);
                $score                  = $_excel->valorCelda(7, $indice_fila);    

                /*
                $_lighthouse->nombre_requestedUrl   = $arr_celda[0];
                $_lighthouse->nombre_finalUrl       = str_replace('"', '' ,$arr_celda[1]);
                $_lighthouse->category              = str_replace('"', '' ,$arr_celda[2]);
                $_lighthouse->name_category         = str_replace('"', '' ,$arr_celda[3]);
                $_lighthouse->title                 = str_replace('"', '' ,$arr_celda[4]);
                $_lighthouse->type                  = str_replace('"', '' ,$arr_celda[5]);
                $_lighthouse->score                 = str_replace('"', '' ,$arr_celda[6]);
                */

                $_lighthouse->nombre_requestedUrl   = $nombre_requestedUrl;
                $_lighthouse->nombre_finalUrl       = $nombre_finalUrl;
                $_lighthouse->category              = $category;
                $_lighthouse->name_category         = $name_category;
                $_lighthouse->title                 = $title;
                $_lighthouse->type                  = $type;
                $_lighthouse->score                 = $score;

                $id_requestedUrl                = $_lighthouse->BuscarCrearRequestedURL();
                $_lighthouse->id_requestedUrl   = $id_requestedUrl;
                $id_final_url                   = $_lighthouse->BuscarCrearNombreFinalUrl();
                $_lighthouse->id_final_url      = $id_final_url;
                $id_category                    = $_lighthouse->BuscarCrearCategory();
                $_lighthouse->id_category       = $id_category;
                $id_name_category               = $_lighthouse->BuscarCrearNameCategory();
                $_lighthouse->id_name_category  = $id_name_category;
                $id_title                       = $_lighthouse->BuscarCrearTitle();
                $_lighthouse->id_title          = $id_title;
                $id_type                        = $_lighthouse->BuscarCrearType();
                $_lighthouse->id_type           = $id_type;
                //print_r($_lighthouse);
                $id_registro                    = $_lighthouse->InsertRegistro();

                $texto_registro = "{$nombre_requestedUrl}||{$nombre_finalUrl}||{$category}||{$name_category}||{$title}||{$type}||{$score}||{$ac}||{$fecha_registro}";
                $texto_registro = str_replace('<', '--', $texto_registro);
                $texto_registro = str_replace('>', '--', $texto_registro);

                echo "\t\t {$texto_registro} \n";
            }
        }
        $comando_llamado    = 'sudo mv ';
        $ruta_original      = ' /var/www/html/lighthouse/archivos/lighthouse/' . $ac . '/' . $nombre_archivo . ' ';
        $ruta_a_mover       = ' /var/www/html/lighthouse/archivos/lighthouse/respaldo/' . $ac . '/' . $nombre_archivo . ' ';
        shell_exec($comando_llamado . $ruta_original . $ruta_a_mover);
    }
}
echo 'Proceso Terminado';
exit;
/*
foreach($leer_archivos as $la){
    $arr_archivos = $arr_datos  = explode('/', $la);
    $tamaño_arreglo = count($arr_archivos)-1;
    print_r($arr_archivos[$tamaño_arreglo]);

    $_excel->Leer($ruta_archivo . $arr_archivos[$tamaño_arreglo]);
    $total_hojas        = $_excel->TotalHojas();
    $hoja_actual        = $_excel->SeleccionarHoja(0);
    $total_filas        = $_excel->TotalFilas();
    //$total_colum        = $_excel->TotalColumnas();
    $cont               = 0;
    for($i = 0; $i <$total_hojas; ++$i){
        $hoja_actual = $_excel->SeleccionarHoja($i);
        for($indice_fila = 2; $indice_fila<=$total_filas; ++$indice_fila){
            ++$cont;
            $dato       = $_excel->valorCelda(1, $indice_fila);
            //$dato       = str_replace('<', '--' ,$dato);
            //$dato       = str_replace('>', '--' ,$dato);
            $arr_datos  = explode(',"', $dato);
    
            print_r($arr_datos);
    
            $_lighthouse->nombre_requestedUrl   = $arr_datos[0];
            $_lighthouse->nombre_finalUrl       = str_replace('"', '' ,$arr_datos[1]);
            $_lighthouse->category              = str_replace('"', '' ,$arr_datos[2]);
            $_lighthouse->name_category         = str_replace('"', '' ,$arr_datos[3]);
            $_lighthouse->title                 = str_replace('"', '' ,$arr_datos[4]);
            $_lighthouse->type                  = str_replace('"', '' ,$arr_datos[5]);
            $_lighthouse->score                 = str_replace('"', '' ,$arr_datos[6]);
    
            $id_requestedUrl                = $_lighthouse->BuscarCrearRequestedURL();
            $_lighthouse->id_requestedUrl   = $id_requestedUrl;
            $id_final_url                   = $_lighthouse->BuscarCrearNombreFinalUrl();
            $_lighthouse->id_final_url      = $id_final_url;
            $id_category                    = $_lighthouse->BuscarCrearCategory();
            $_lighthouse->id_category       = $id_category;
            $id_name_category               = $_lighthouse->BuscarCrearNameCategory();
            $_lighthouse->id_name_category  = $id_name_category;
            $id_title                       = $_lighthouse->BuscarCrearTitle();
            $_lighthouse->id_title          = $id_title;
            $id_type                        = $_lighthouse->BuscarCrearType();
            $_lighthouse->id_type           = $id_type;
    
            $id_registro                    = $_lighthouse->InsertRegistro();
        }
    }

}
exit;



echo "Total Datos: {$cont}";*/

?>